import type { GetRoleListParams, MenuTreeNode, Role } from './types'
import { defHttp } from '@/utils/http/axios'

export function lazyGetRoleList(params: GetRoleListParams) {
  return defHttp.get<Role[]>({
    url: '/system/role/lazy-list',
    params,
  })
}

export function createRole(data: Partial<Role>) {
  return defHttp.post({
    url: '/system/role/save',
    data,
  })
}

export function updateRole(data: Partial<Role>) {
  return defHttp.post({
    url: '/system/role/update',
    data,
  })
}

export function deleteRole(id: string) {
  return defHttp.post({
    url: `/system/role/delete?id=${id}`,
  })
}

export function getRoleTree(params?: { tenantId: string }) {
  return defHttp.get<{ id: string, title: string }[]>({
    url: '/system/role/tree',
    params,
  })
}

export function getMenuTree() {
  return defHttp.get<MenuTreeNode[]>({
    url: '/system/menu/grant-tree',
  })
}

export function getMenuIdsByRole(roleId: string) {
  return defHttp.get<string[]>({
    url: '/system/permission/list-role-menus',
    params: { roleId },
  })
}

export function assignMenuToRole(data: { roleId: string, menuIds: string[] }) {
  return defHttp.post({
    url: '/system/permission/assign-role-menu',
    data,
  })
}
