import { lazyGetDeptList } from '@/api/system/dept'
import { getAllTenants } from '@/api/system/tenant'
import type { BasicColumn, FormSchema } from '@/components/Table'

export const columns: BasicColumn[] = [
  {
    title: '部门名称',
    dataIndex: 'deptName',
    width: 260,
    align: 'left',
  },
  {
    title: '所属租户',
    dataIndex: 'tenantName',
    width: 120,
  },
]

export const searchFormSchema: FormSchema[] = [
  {
    label: '部门名称',
    field: 'deptName',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '所属租户',
    field: 'tenantId',
    component: 'ApiSelect',
    componentProps: {
      api: getAllTenants,
      valueField: 'tenantId',
      labelField: 'tenantName',
    },
    colProps: { span: 6 },
  },
]

export const formSchema: FormSchema[] = [
  {
    field: 'id',
    show: false,
    component: 'Input',
  },
  {
    label: '上级部门',
    field: 'parentId',
    component: 'ApiTreeSelect',
    componentProps: {
      async api() {
        try {
          const res = await lazyGetDeptList()
          return res.map(item => ({ ...item, isLeaf: !item.hasChildren }))
        }
        catch {
          return []
        }
      },
      async loadData(treeNode) {
        try {
          const res = await lazyGetDeptList({ parentId: treeNode.id })
          return res.map(item => ({ ...item, isLeaf: !item.hasChildren }))
        }
        catch {
          return []
        }
      },
      valueField: 'id',
      labelField: 'deptName',
    },
  },
  {
    label: '部门名称',
    field: 'deptName',
    required: true,
    component: 'Input',
  },
  {
    label: '显示顺序',
    field: 'sort',
    required: true,
    defaultValue: 0,
    component: 'InputNumber',
  },
]
