import { Tag } from 'ant-design-vue'
import { getMenuListWithoutButtons } from '@/api/system/menu'
import type { BasicColumn, FormSchema } from '@/components/Table'
import { SystemMenuTypeEnum } from '@/api/system/menu/types'

export const columns: BasicColumn[] = [
  {
    title: '菜单名称',
    dataIndex: 'name',
    width: 250,
    align: 'left',
  },
  {
    title: '菜单类型',
    dataIndex: 'type',
    width: 80,
    customRender: ({ record }) => {
      const { type } = record
      let name = ''
      switch (type) {
        case SystemMenuTypeEnum.DIR:
          name = '目录'
          break
        case SystemMenuTypeEnum.MENU:
          name = '菜单'
          break
        default:
          name = '按钮'
      }

      return <Tag>{ name }</Tag>
    },
  },
  {
    title: '图标',
    dataIndex: 'icon',
    width: 60,
    customRender: ({ record }) => {
      return record.icon && <span class={record.icon}></span>
    },
  },
  {
    title: '排序',
    dataIndex: 'sort',
    width: 60,
  },
  {
    title: '权限标识',
    dataIndex: 'code',
    width: 140,
  },
  {
    title: '路由路径',
    dataIndex: 'path',
    width: 140,
  },
  {
    title: '组件路径',
    dataIndex: 'component',
    width: 140,
  },
]

export const searchFormSchema: FormSchema[] = [
  {
    label: '菜单名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    label: '权限标识',
    field: 'code',
    component: 'Input',
    colProps: { span: 8 },
  },
]

export const formSchema: FormSchema[] = [
  {
    field: 'id',
    show: false,
    component: 'Input',
  },
  {
    label: '上级菜单',
    field: 'parentId',
    component: 'ApiTreeSelect',
    componentProps: {
      api: getMenuListWithoutButtons,
      labelField: 'title',
      valueField: 'id',
    },
  },
  {
    label: '菜单类型',
    field: 'type',
    required: true,
    defaultValue: 1,
    component: 'RadioButtonGroup',
    componentProps: {
      options: [
        {
          label: '目录',
          value: SystemMenuTypeEnum.DIR,
        },
        {
          label: '菜单',
          value: SystemMenuTypeEnum.MENU,
        },
        {
          label: '按钮',
          value: SystemMenuTypeEnum.BUTTON,
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '菜单名称',
    field: 'name',
    required: true,
    component: 'Input',
  },
  {
    label: '菜单图标',
    field: 'icon',
    component: 'IconPicker',
    ifShow: ({ values }) => values.type !== SystemMenuTypeEnum.BUTTON,
  },
  {
    label: '显示排序',
    field: 'sort',
    required: true,
    component: 'InputNumber',
    defaultValue: 0,
  },
  {
    label: '路由地址',
    field: 'path',
    required: true,
    component: 'Input',
    helpMessage: '访问的路由地址，如：`user`。如需外网地址时，则以 `http(s)://` 开头',
    ifShow: ({ values }) => values.type !== SystemMenuTypeEnum.BUTTON,
  },
  {
    label: '组件路径',
    field: 'component',
    required: true,
    component: 'Input',
    helpMessage: '例如：system/user/index，不定义时使用 path 字段',
    ifShow: ({ values }) => values.type === SystemMenuTypeEnum.MENU,
  },
  {
    label: '组件名称',
    field: 'componentName',
    required: ({ values }) => values.keepAlive,
    component: 'Input',
    helpMessage: '例如：SystemName，当开启缓存时它是必传的',
    ifShow: ({ values }) => values.type === SystemMenuTypeEnum.MENU,
  },
  {
    label: '权限标识',
    field: 'code',
    required: true,
    component: 'Input',
    helpMessage: '输入一个不重复的标识',
  },
  {
    label: '是否在菜单栏显示',
    field: 'visible',
    component: 'Switch',
    componentProps: {
      checkedChildren: '显示',
      unCheckedChildren: '隐藏',
      checkedValue: 1,
      unCheckedValue: 0,
    },
    defaultValue: 1,
    helpMessage: '选择隐藏时，路由将不会出现在侧边栏，但仍然可以访问',
    ifShow: ({ values }) => values.type !== SystemMenuTypeEnum.BUTTON,
  },
  {
    label: '是否缓存',
    field: 'keepAlive',
    component: 'Switch',
    componentProps: {
      checkedChildren: '缓存',
      unCheckedChildren: '不缓存',
      checkedValue: 1,
      unCheckedValue: 0,
    },
    helpMessage: '选择缓存时，则会被 `keep-alive` 缓存，同时必须指定组件的 Name 值',
    ifShow: ({ values }) => values.type === SystemMenuTypeEnum.MENU,
  },
]
